@@ -1,4 +1,4 @@
-# Copyright (c) 2023 The pymovements Project Authors
+# Copyright (c) 2023-2025 The pymovements Project Authors
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -22,8 +22,21 @@ from __future__ import annotations
 
 
 class InvalidProperty(Exception):
-    """Raised if requested property is invalid."""
+    """Raised if requested property is invalid.
+
+    Parameters
+    ----------
+    property_name: str
+        Name of the property which is invalid.
+
+    valid_properties: list[str]
+        List of valid properties.
+    """
 
     def __init__(self, property_name: str, valid_properties: list[str]):
         message = f"property '{property_name}' is invalid. Valid properties are: {valid_properties}"
         super().__init__(message)
+
+
+class UnknownFileType(RuntimeError):
+    """Raised on unknown file types."""
