@@ -1,4 +1,4 @@
-# Copyright (c) 2022-2023 The pymovements Project Authors
+# Copyright (c) 2022-2025 The pymovements Project Authors
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -17,14 +17,10 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
-"""This module holds functionality for generating synthetic eye gaze data.
+"""Provides functionality for generating synthetic eye gaze data."""
+from pymovements.synthetic.step_function import step_function
 
-.. rubric:: Functions
 
-.. autosummary::
-   :toctree:
-
-    pymovements.synthetic.step_function
-
-"""
-from pymovements.synthetic.step_function import step_function  # noqa: F401
+__all__ = [
+    'step_function',
+]
