@@ -1,4 +1,4 @@
-# Copyright (c) 2022-2023 The pymovements Project Authors
+# Copyright (c) 2022-2025 The pymovements Project Authors
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -17,9 +17,7 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
-"""
-This module holds the synthetic eye gaze step function.
-"""
+"""Provides the synthetic step function."""
 from __future__ import annotations
 
 from collections.abc import Sized
@@ -33,27 +31,29 @@ def step_function(
         values: list[float | tuple[float, ...]],
         start_value: float | tuple[float, ...] = 0,
         noise: float = 0,
+        dtype: np.typing.DTypeLike = np.float64,
 ) -> np.ndarray:
-    """
-    Create a synthetic eye gaze by using a simple step function.
+    """Create a synthetic eye gaze by using a simple step function.
 
     Parameters
     ----------
-    length : int
+    length: int
         Length of the output sequence.
-    steps : list[int]
+    steps: list[int]
         Indices for each step to happen.
-    values : list[float]
+    values: list[float | tuple[float, ...]]
         Array values to set at each step.
-    start_value: int
-        Array value to start with.
+    start_value: float | tuple[float, ...]
+        Array value to start with. (default: 0)
     noise: float
         If greater than zero, gaussian noise is scaled according to value and superimposed on the
-        output array.
+        output array. (default: 0)
+    dtype: np.typing.DTypeLike
+        The desired data type of the output array. (default: np.float64)
 
     Returns
     -------
-    arr : np.ndarray
+    np.ndarray
         Output signal
 
     Raises
@@ -70,7 +70,7 @@ def step_function(
     ...     values=[1., 2., 3.],
     ...     start_value=0,
     ... )
-    array([0., 0., 1., 1., 1., 2., 2., 2., 2., 3.], dtype=float32)
+    array([0., 0., 1., 1., 1., 2., 2., 2., 2., 3.])
 
     >>> # multi-channel example
     >>> step_function(
@@ -88,7 +88,7 @@ def step_function(
            [ 3.,  4.],
            [ 3.,  4.],
            [ 3.,  4.],
-           [ 3.,  4.]], dtype=float32)
+           [ 3.,  4.]])
     """
     # Check that steps and values have equal length.
     if len(steps) != len(values):
@@ -136,8 +136,8 @@ def step_function(
     else:
         arr = np.tile(start_value, (length, 1))
 
-    # change type of elements to float32, to allow np.nan
-    arr = np.array(arr, dtype=np.float32)
+    # create array of requested dtype.
+    arr = np.array(arr, dtype=dtype)
 
     # Iterate through all steps except the last.
     for begin, end, value in zip(steps[:-1], steps[1:], values[:-1]):
